import {ChangeDetectionStrategy, Component, OnInit} from '@angular/core';
import {MatDialog} from '@angular/material';
import {GetAll} from '@app/deposit/deposit.action';
import {DepositStateModel} from '@app/deposit/deposit.state';
import {RoutesEnum} from '@app/enums/routes.enum';
import {StateEnum} from '@app/enums/state.enum';
import {DepositsModel} from '@app/generated-api';
import {faCoffee} from '@fortawesome/free-solid-svg-icons';
import {Navigate} from '@ngxs/router-plugin';
import {Select, Store} from '@ngxs/store';
import {Observable} from 'rxjs';

@Component({
  selector: 'dlcm-deposit-view',
  templateUrl: './deposit-view.component.html',
  styleUrls: ['./deposit-view.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class DepositViewComponent implements OnInit {
  faCoffee = faCoffee;

  @Select((state) => (state[StateEnum.deposit] as DepositStateModel).isLoading) isLoading$: Observable<boolean>;
  @Select((state) => (state[StateEnum.deposit] as DepositStateModel).deposits) deposits$: Observable<DepositsModel[]>;

  constructor(private store: Store, public dialog: MatDialog) {
  }

  ngOnInit() {
    this.getAll();
  }

  getAll() {
    this.store.dispatch(new GetAll());
  }

  createNewDeposit() {
    // const dialogRef = this.dialog.open(CreateDepositContainerComponent, {
    //   height: '400px',
    //   width: '600px',
    // });
    this.store.dispatch(new Navigate([RoutesEnum.depositCreate]));
  }

  showDetail(resId: string) {
    this.store.dispatch(new Navigate([RoutesEnum.depositDetail, resId]));
  }
}
