import {ChangeDetectionStrategy, Component, EventEmitter, Input, OnInit, Output} from '@angular/core';
import {FormBuilder, FormGroup, Validators} from '@angular/forms';
import {OrganizationalUnitsModel} from '@app/generated-api';
import {DateUtil} from '@app/shared/utils/date.util';

@Component({
  selector: 'dlcm-create-organizational-units',
  templateUrl: './create-organizational-units.component.html',
  styleUrls: ['./create-organizational-units.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class CreateOrganizationalUnitsComponent implements OnInit {
  createOrganizationalUnitForm: FormGroup;
  name = 'name';
  description = 'description';
  isEmpty = 'isEmpty';
  closingDate = 'closingDate';
  openingDate = 'openingDate';
  open = 'open';

  @Input()
  organizationalUnit: OrganizationalUnitsModel;

  @Output()
  submitEvent: EventEmitter<any>;

  constructor(private fb: FormBuilder) {
    this.submitEvent = new EventEmitter<any>();
  }

  ngOnInit() {
    if (this.organizationalUnit) {
      this.bindFormTo(this.organizationalUnit);
    } else {
      this.initNewForm();
    }
  }

  private initNewForm() {
    this.createOrganizationalUnitForm = this.fb.group({
      name: ['', Validators.required],
      description: ['', Validators.required],
      openingDate: [''],
      closingDate: [''],
      isEmpty: [false],
      open: [false],
    });
  }

  private bindFormTo(organizationalUnit: OrganizationalUnitsModel) {
    this.createOrganizationalUnitForm = this.fb.group({
      name: [organizationalUnit.name, Validators.required],
      description: [organizationalUnit.description, Validators.required],
      openingDate: [organizationalUnit.openingDate],
      closingDate: [organizationalUnit.closingDate],
      isEmpty: [organizationalUnit.isEmpty],
      open: [organizationalUnit.open],
    });
  }


  onSubmit() {
    const organizationalUnit = this.createOrganizationalUnitForm.value as OrganizationalUnitsModel;
    organizationalUnit.openingDate = DateUtil.convertToISO8601(organizationalUnit.openingDate);
    organizationalUnit.closingDate = DateUtil.convertToISO8601(organizationalUnit.closingDate);
    this.addResId(organizationalUnit);
    this.submitEvent.emit(organizationalUnit);
  }

  private addResId(organizationalUnit: OrganizationalUnitsModel) {
    const isUpdate = this.organizationalUnit !== null;
    if (isUpdate) {
      organizationalUnit.resId = this.organizationalUnit.resId;
    }
  }
}
