import {ChangeDetectionStrategy, Component, OnInit} from '@angular/core';
import {ActivatedRoute} from '@angular/router';
import {StateEnum} from '@app/enums/state.enum';
import {OrganizationalUnitsModel} from '@app/generated-api';
import {GetById, Update} from '@app/organizational-unit/organizational-unit.action';
import {OrganizationalUnitStateModel} from '@app/organizational-unit/organizational-unit.state';
import {Select, Store} from '@ngxs/store';
import {Observable} from 'rxjs';

@Component({
  selector: 'dlcm-edit-view',
  templateUrl: './edit-view.component.html',
  styleUrls: ['./edit-view.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class EditViewComponent implements OnInit {
  @Select((state) => (state[StateEnum.organizationalUnit] as OrganizationalUnitStateModel).isLoading) isLoading$: Observable<boolean>;
  @Select((state) => (state[StateEnum.organizationalUnit] as OrganizationalUnitStateModel).currentOrganizationalUnit) currentOrganizationalUnit$: Observable<OrganizationalUnitsModel>;

  private resId: string;

  constructor(private store: Store, private route: ActivatedRoute) {
  }

  ngOnInit() {
    this.getCurrentOrganizationalUnit();
  }

  private getCurrentOrganizationalUnit() {
    this.resId = this.route.snapshot.paramMap.get('id');
    this.getById(this.resId);
  }

  private getById(id: string) {
    this.store.dispatch(new GetById(id));
  }

  update(organizationalUnit: OrganizationalUnitsModel) {
    this.store.dispatch(new Update(organizationalUnit));
  }
}
