import {ChangeDetectionStrategy, Component, OnInit} from '@angular/core';
import {RoutesEnum} from '@app/enums/routes.enum';
import {StateEnum} from '@app/enums/state.enum';
import {OrganizationalUnitsModel} from '@app/generated-api';
import {GetAll} from '@app/organizational-unit/organizational-unit.action';
import {OrganizationalUnitStateModel} from '@app/organizational-unit/organizational-unit.state';
import {Navigate} from '@ngxs/router-plugin';
import {Select, Store} from '@ngxs/store';
import {Observable} from 'rxjs';

@Component({
  selector: 'dlcm-organizational-unit-view',
  templateUrl: './organizational-unit-view.component.html',
  styleUrls: ['./organizational-unit-view.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class OrganizationalUnitViewComponent implements OnInit {
  @Select((state) => (state[StateEnum.organizationalUnit] as OrganizationalUnitStateModel).isLoading) isLoading$: Observable<boolean>;
  @Select((state) => (state[StateEnum.organizationalUnit] as OrganizationalUnitStateModel).organizationalUnits) organizationalUnits$: Observable<OrganizationalUnitsModel[]>;

  constructor(private store: Store) {
  }

  ngOnInit() {
    this.getAll();
  }

  createNewOrganizationalUnit() {
    this.store.dispatch(new Navigate([RoutesEnum.organizationalUnitCreate]));
  }

  getAll() {
    this.store.dispatch(new GetAll());
  }

  showDetail(resId: string) {
    this.store.dispatch(new Navigate([RoutesEnum.organizationalUnitDetail, resId]));
  }
}
