import {ChangeDetectionStrategy, Component, OnInit} from '@angular/core';
import {MatDialog} from '@angular/material';
import {ActivatedRoute} from '@angular/router';
import {RoutesEnum} from '@app/enums/routes.enum';
import {StateEnum} from '@app/enums/state.enum';
import {OrganizationalUnitsModel} from '@app/generated-api';
import {DeleteDialogComponent} from '@app/organizational-unit/dialogs/delete-dialog/delete-dialog.component';
import {DeleteDialogModel} from '@app/organizational-unit/models/delete-dialog.model';
import {GetById} from '@app/organizational-unit/organizational-unit.action';
import {OrganizationalUnitStateModel} from '@app/organizational-unit/organizational-unit.state';
import {Navigate} from '@ngxs/router-plugin';
import {Select, Store} from '@ngxs/store';
import {Observable} from 'rxjs';
import {take} from 'rxjs/operators';

@Component({
  selector: 'dlcm-organizational-unit-detail-view',
  templateUrl: './organizational-unit-detail-view.component.html',
  styleUrls: ['./organizational-unit-detail-view.component.scss'],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class OrganizationalUnitDetailViewComponent implements OnInit {
  @Select((state) => (state[StateEnum.organizationalUnit] as OrganizationalUnitStateModel).isLoading) isLoading$: Observable<boolean>;
  @Select((state) => (state[StateEnum.organizationalUnit] as OrganizationalUnitStateModel).currentOrganizationalUnit) currentOrganizationalUnit$: Observable<OrganizationalUnitsModel>;

  private resId: string;

  constructor(private store: Store,
              private route: ActivatedRoute,
              public dialog: MatDialog) {
  }

  ngOnInit() {
    this.getCurrentOrganizationalUnit();
  }

  private getCurrentOrganizationalUnit() {
    this.resId = this.route.snapshot.paramMap.get('id');
    this.getById(this.resId);
  }

  private getById(id: string) {
    this.store.dispatch(new GetById(id));
  }

  edit() {
    this.store.dispatch(new Navigate([RoutesEnum.organizationalUnitEdit, this.resId]));
  }

  delete() {
    const datas = {} as DeleteDialogModel;
    this.currentOrganizationalUnit$.pipe(take(1)).subscribe((orgUnit: OrganizationalUnitsModel) => {
      datas.organizationalUnitName = orgUnit.name;
      datas.organizationalUnitId = orgUnit.resId;
    });
    const dialogRef = this.dialog.open(DeleteDialogComponent, {
      width: '250px',
      data: datas,
    });
  }
}
