import {AppStateModel} from '@app/app.state';
import {StateEnum} from '@app/enums/state.enum';
import {LanguagesModel} from '@app/generated-api';
import {CollectionTypedModel} from '@app/shared/models/collection-typed.model';
import {DlcmExtendedService} from '@app/service/dlcm.extended.service';
import {GetAllLanguages, GetAllLanguagesFail, GetAllLanguagesSuccess} from '@app/shared/language.action';
import {Action, State, StateContext} from '@ngxs/store';
import {catchError} from 'rxjs/internal/operators/catchError';
import {tap} from 'rxjs/operators';

export interface LanguageStateModel extends AppStateModel {
  languages: LanguagesModel[];
}

@State<LanguageStateModel>({
  name: StateEnum.language,
  defaults: {
    languages: [],
    isLoading: false,
  },
})
export class LanguageState {
  constructor(private dlcmService: DlcmExtendedService) {
  }

  @Action(GetAllLanguages, {cancelUncompleted: true})
  getAllLanguages(ctx: StateContext<LanguageStateModel>, action: GetAllLanguages) {
    ctx.patchState({
      isLoading: true,
    });

    return this.dlcmService.adminLanguagesGet()
      .pipe(
        tap((collectionLanguages: CollectionTypedModel<LanguagesModel>) => {
          ctx.dispatch(new GetAllLanguagesSuccess(collectionLanguages));
        }),
        catchError(error => {
          ctx.dispatch(new GetAllLanguagesFail());
          throw error;
        }),
      );
  }

  @Action(GetAllLanguagesSuccess)
  getAllLanguagesSuccess(ctx: StateContext<LanguageStateModel>, action: GetAllLanguagesSuccess) {
    ctx.patchState({
      languages: action.languages._data,
      isLoading: false,
    });
  }

  @Action(GetAllLanguagesFail)
  getAllLanguagesFail(ctx: StateContext<LanguageStateModel>) {
    ctx.patchState({
      isLoading: false,
    });
  }
}



