import {AppStateModel} from '@app/app.state';
import {StateEnum} from '@app/enums/state.enum';
import {LanguagesModel, LicensesModel} from '@app/generated-api';
import {CollectionTypedModel} from '@app/shared/models/collection-typed.model';
import {DlcmExtendedService} from '@app/service/dlcm.extended.service';
import {GetAllLicenses, GetAllLicensesFail, GetAllLicensesSuccess} from '@app/shared/license.action';
import {Action, State, StateContext} from '@ngxs/store';
import {catchError} from 'rxjs/internal/operators/catchError';
import {tap} from 'rxjs/operators';

export interface LicenseStateModel extends AppStateModel {
  licenses: LicensesModel[];
}

@State<LicenseStateModel>({
  name: StateEnum.license,
  defaults: {
    licenses: [],
    isLoading: false,
  },
})
export class LicenseState {
  constructor(private dlcmService: DlcmExtendedService) {
  }

  @Action(GetAllLicenses, {cancelUncompleted: true})
  getAllLicenses(ctx: StateContext<LicenseStateModel>, action: GetAllLicenses) {
    ctx.patchState({
      isLoading: true,
    });

    return this.dlcmService.adminLicensesGet()
      .pipe(
        tap((collectionLicenses: CollectionTypedModel<LicensesModel>) => {
          ctx.dispatch(new GetAllLicensesSuccess(collectionLicenses));
        }),
        catchError(error => {
          ctx.dispatch(new GetAllLicensesFail());
          throw error;
        }),
      );
  }

  @Action(GetAllLicensesSuccess)
  getAllLicensesSuccess(ctx: StateContext<LicenseStateModel>, action: GetAllLicensesSuccess) {
    ctx.patchState({
      licenses: action.licenses._data,
      isLoading: false,
    });
  }

  @Action(GetAllLicensesFail)
  getAllLicensesFail(ctx: StateContext<LicenseStateModel>) {
    ctx.patchState({
      isLoading: false,
    });
  }
}



