import {AppStateModel} from '@app/app.state';
import {StateEnum} from '@app/enums/state.enum';
import {LanguagesModel} from '@app/generated-api';
import {CollectionTypedModel} from '@app/shared/models/collection-typed.model';
import {DlcmExtendedService} from '@app/service/dlcm.extended.service';
import {GetAllLanguages} from '@app/shared/language.action';
import {LanguageState} from '@app/shared/language.state';
import {GetAllLicenses} from '@app/shared/license.action';
import {LicenseState} from '@app/shared/license.state';
import {GetAllResources, GetAllResourcesFail, GetAllResourcesSuccess} from '@app/shared/shared.action';
import {Action, State, StateContext} from '@ngxs/store';
import {catchError} from 'rxjs/internal/operators/catchError';
import {tap} from 'rxjs/operators';

export interface SharedStateModel extends AppStateModel {
}

@State<SharedStateModel>({
  name: StateEnum.shared,
  defaults: {
    isLoading: false,
  },
  children: [
    LanguageState,
    LicenseState,
  ],
})
export class SharedState {
  constructor(private dlcmService: DlcmExtendedService) {
  }

  @Action(GetAllResources, {cancelUncompleted: true})
  getAllResources(ctx: StateContext<SharedStateModel>, action: GetAllResources) {
    ctx.patchState({
      isLoading: true,
    });

    return this.dlcmService.adminLanguagesGet()
      .pipe(
        tap((collectionLanguages: CollectionTypedModel<LanguagesModel>) => {
          ctx.dispatch(new GetAllLanguages());
          ctx.dispatch(new GetAllLicenses());
          ctx.dispatch(new GetAllResourcesSuccess());
        }),
        catchError(error => {
          ctx.dispatch(new GetAllResourcesFail());
          throw error;
        }),
      );
  }

  @Action(GetAllResourcesSuccess)
  getAllResourcesSuccess(ctx: StateContext<SharedStateModel>, action: GetAllResourcesSuccess) {
    ctx.patchState({
      isLoading: false,
    });
  }

  @Action(GetAllResourcesFail)
  getAllResourcesFail(ctx: StateContext<SharedStateModel>) {
    ctx.patchState({
      isLoading: false,
    });
  }
}



